@@ -41,15 +41,6 @@ current_heat_template_version = valid_heat_template_versions[-1]
 required_params = ['EndpointMap', 'ServiceNetMap', 'RoleName',
                    'RoleParameters', 'ServiceData']
 
-# NOTE(bnemec): The duplication in this list is intentional.  For the
-# transition to generated environments we have two copies of these files,
-# so they need to be listed twice.  Once the deprecated version can be removed
-# the duplicate entries can be as well.
-envs_containing_endpoint_map = ['no-tls-endpoints-public-ip.yaml',
-                                'tls-endpoints-public-dns.yaml',
-                                'tls-endpoints-public-ip.yaml',
-                                'tls-everywhere-endpoints-dns.yaml']
-ENDPOINT_MAP_FILE = 'endpoint_map.yaml'
 OPTIONAL_SECTIONS = ['ansible_group_vars',
                      'cellv2_discovery',
                      'firewall_rules',
@@ -267,15 +258,6 @@ CONFIG_RESOURCE_TYPES = [
 
 WORKFLOW_TASKS_EXCLUSIONS = [
     './deployment/octavia/octavia-deployment-config.yaml',
-    './deployment/ceph-ansible/ceph-external.yaml',
-    './deployment/ceph-ansible/ceph-osd.yaml',
-    './deployment/ceph-ansible/ceph-rbdmirror.yaml',
-    './deployment/ceph-ansible/ceph-client.yaml',
-    './deployment/ceph-ansible/ceph-mds.yaml',
-    './deployment/ceph-ansible/ceph-rgw.yaml',
-    './deployment/ceph-ansible/ceph-base.yaml',
-    './deployment/ceph-ansible/ceph-mon.yaml',
-    './deployment/ceph-ansible/ceph-mgr.yaml',
 ]
 
 
@@ -305,62 +287,23 @@ def to_camel_case(string):
                                                     s in string.split('_')))
 
 
-def get_base_endpoint_map(filename):
-    try:
-        with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
-        return tpl['parameters']['EndpointMap']['default']
-    except Exception:
-        print(traceback.format_exc())
-    return None
-
-
-def get_endpoint_map_from_env(filename):
-    try:
-        with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
-        return {
-            'file': filename,
-            'map': tpl['parameter_defaults']['EndpointMap']
-        }
-    except Exception:
-        print(traceback.format_exc())
-    return None
-
-
 def compare_parameters(old_impl_path, new_impl_path):
     old_impl_params = []
     new_impl_params = []
     for filename in glob.glob(old_impl_path + "/*.yaml"):
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+            tpl = yaml.safe_load(f.read())
             old_impl_params.extend(tpl["parameters"].keys())
     for filename in glob.glob(new_impl_path + "/*.yaml"):
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+            tpl = yaml.safe_load(f.read())
             new_impl_params.extend(tpl["parameters"].keys())
     return set(old_impl_params).difference(set(new_impl_params))
 
 
-def compare_ceph_parameters(path):
-    old_path = base_path + "/deployment/ceph-ansible/"
-    new_path = base_path + "/deployment/cephadm/"
-    missing = compare_parameters(old_path, new_path)
-    if missing:
-        print("ERROR: Some parameters are missing in Ceph implementation at"
-              "'%s' compared to that in '%s' and they are: %s" %
-              (new_path, old_path, missing))
-        return 1
-    return 0
-
-
-def validate_endpoint_map(base_map, env_map):
-    return sorted(base_map.keys()) == sorted(env_map.keys())
-
-
 def validate_role_name(filename):
     with open(filename, 'r') as f:
-        tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+        tpl = yaml.safe_load(f.read())
 
     role_data = tpl[0]
     if role_data['name'] != os.path.basename(filename).split('.')[0]:
@@ -376,7 +319,7 @@ def validate_hci_compute_services_default(env_filename, env_tpl):
     roles_filename = os.path.join(os.path.dirname(env_filename),
                                   '../roles/Compute.yaml')
     with open(roles_filename, 'r') as f:
-        roles_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+        roles_tpl = yaml.safe_load(f.read())
 
     for role in roles_tpl:
         if role['name'] == 'Compute':
@@ -392,7 +335,7 @@ def validate_hci_computehci_role(hci_role_filename, hci_role_tpl):
     compute_role_filename = os.path.join(os.path.dirname(hci_role_filename),
                                          './Compute.yaml')
     with open(compute_role_filename, 'r') as f:
-        compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+        compute_role_tpl = yaml.safe_load(f.read())
 
     compute_role_services = compute_role_tpl[0]['ServicesDefault']
     for role in hci_role_tpl:
@@ -410,7 +353,7 @@ def validate_controller_dashboard(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+        control_role_tpl = yaml.safe_load(f.read())
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -427,7 +370,7 @@ def validate_controller_storage_nfs(filename, tpl, exclude_service=()):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+        control_role_tpl = yaml.safe_load(f.read())
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -446,7 +389,7 @@ def validate_hci_role(hci_role_filename, hci_role_tpl):
         compute_role_filename = \
             os.path.join(os.path.dirname(hci_role_filename), './Compute.yaml')
         with open(compute_role_filename, 'r') as f:
-            compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+            compute_role_tpl = yaml.safe_load(f.read())
 
         compute_role_services = compute_role_tpl[0]['ServicesDefault']
         for role in hci_role_tpl:
@@ -485,7 +428,7 @@ def validate_ceph_role(ceph_role_filename, ceph_role_tpl):
         ceph_storage_role_filename = \
             os.path.join(os.path.dirname(ceph_role_filename), './CephStorage.yaml')
         with open(ceph_storage_role_filename, 'r') as f:
-            ceph_storage_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+            ceph_storage_role_tpl = yaml.safe_load(f.read())
 
         ceph_storage_role_services = ceph_storage_role_tpl[0]['ServicesDefault']
         for role in ceph_role_tpl:
@@ -516,7 +459,7 @@ def validate_controller_no_ceph_role(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+        control_role_tpl = yaml.safe_load(f.read())
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -539,7 +482,7 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     with open(cmpt_filename, 'r') as f:
-        cmpt_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+        cmpt_tpl = yaml.safe_load(f.read())
 
     cmpt_services = cmpt_tpl[0]['ServicesDefault']
     cmpt_services = [x for x in cmpt_services if (x not in exclude_service)]
@@ -678,7 +621,7 @@ def validate_docker_service_mysql_usage(filename, tpl):
                     os.path.exists(newfilename.replace('.yaml', '.j2.yaml')):
                     return  # Skip for now if it's templated
                 with open(newfilename, 'r') as newfile:
-                    newtmp = yaml.load(newfile.read(), Loader=yaml.SafeLoader)
+                    newtmp = yaml.safe_load(newfile.read())
                 read_all(newfilename, newtmp)
 
     read_all(filename, tpl)
@@ -725,9 +668,7 @@ def validate_docker_service(filename, tpl):
 
         for section_name in REQUIRED_DOCKER_SECTIONS_OVERRIDES.get(filename, REQUIRED_DOCKER_SECTIONS):
             if section_name not in role_data:
-                # add an exception if both step_config is used in docker
-                # service, deployment/ceph-ansible/ceph-nfs.yaml uses
-                # additional step_config to add pacemaker resources
+                # add an exception if both step_config is used in docker service
                 if (section_name == 'docker_config' and
                         role_data.get('step_config', '')):
                     print('ERROR: %s appears to be a barematal-puppet service'
@@ -1139,7 +1080,7 @@ def validate(filename, param_map):
     retval = 0
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+            tpl = yaml.safe_load(f.read())
 
         is_heat_template = 'heat_template_version' in tpl
 
@@ -1203,12 +1144,12 @@ def validate(filename, param_map):
 
         if filename.startswith('./roles/ControllerStorageDashboard.yaml'):
             retval |= validate_controller_dashboard(filename, tpl)
-
-        if filename.startswith('./roles/ComputeOvsDpdk.yaml') or \
-                filename.startswith('./roles/ComputeSriov.yaml') or \
-                filename.startswith('./roles/ComputeOvsDpdkRT.yaml') or \
-                filename.startswith('./roles/ComputeSriovRT.yaml') or \
-                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
+        if filename in ['./roles/ComputeOvsDpdk.yaml',
+                        './roles/ComputeSriov.yaml',
+                        './roles/ComputeOvsDpdkRT.yaml',
+                        './roles/ComputeSriovRT.yaml',
+                        './roles/ComputeHCIOvsDpdk.yaml',
+                        './roles/ComputeVdpa.yaml']:
             exclude = [
                 'OS::TripleO::Services::OVNController',
                 'OS::TripleO::Services::ComputeNeutronOvsAgent',
@@ -1245,7 +1186,8 @@ def validate(filename, param_map):
         # definition instead.
         if (filename.startswith('./network_data_') and
                 not filename.endswith(('routed.yaml',
-                                       'undercloud.yaml'))):
+                                       'undercloud.yaml',
+                                       'default.yaml'))):
             result = validate_network_data_file(filename)
             retval |= result
         else:
@@ -1332,11 +1274,11 @@ def validate_upgrade_tasks(upgrade_tasks):
 def validate_network_data_file(data_file_path):
     try:
         with open(data_file_path, 'r') as data_file:
-            data_file = yaml.load(data_file.read(), Loader=yaml.SafeLoader)
+            data_file = yaml.safe_load(data_file.read())
 
         base_file_path = os.path.dirname(data_file_path) + "/network_data.yaml"
         with open(base_file_path, 'r') as base_file:
-            base_file = yaml.load(base_file.read(), Loader=yaml.SafeLoader)
+            base_file = yaml.safe_load(base_file.read())
 
         retval = 0
         for n in base_file:
@@ -1376,6 +1318,10 @@ def parse_args():
                    action='count',
                    default=0,
                    help='output warnings and errors (-q) or only errors (-qq)')
+    p.add_argument('--skip-dir',
+                   action='append',
+                   dest='skip_dirs',
+                   help='The directories to be skipped during file search')
     p.add_argument('path_args',
                    nargs='*',
                    default=['.'])
@@ -1384,6 +1330,7 @@ def parse_args():
 
 
 args = parse_args()
+skip_dirs = args.skip_dirs
 path_args = args.path_args
 quiet = args.quiet
 exit_val = 0
@@ -1394,10 +1341,17 @@ param_map = {}
 
 for base_path in path_args:
     if os.path.isdir(base_path):
-        exit_val |= compare_ceph_parameters(base_path)
         for subdir, dirs, files in os.walk(base_path):
-            if '.tox' in dirs:
-                dirs.remove('.tox')
+            for skip_dir in skip_dirs:
+                if subdir.startswith(os.path.join('.', skip_dir, '')):
+                    skip = True
+                    break
+            else:
+                skip = False
+
+            if skip:
+                continue
+
             for f in files:
                 file_path = os.path.join(subdir, f)
                 if 'tools/tests/nic_config_convert_samples' in file_path:
@@ -1415,12 +1369,6 @@ for base_path in path_args:
                     if failed:
                         failed_files.append(file_path)
                     exit_val |= failed
-                    if f == ENDPOINT_MAP_FILE:
-                        base_endpoint_map = get_base_endpoint_map(file_path)
-                    if f in envs_containing_endpoint_map:
-                        env_endpoint_map = get_endpoint_map_from_env(file_path)
-                        if env_endpoint_map:
-                            env_endpoint_maps.append(env_endpoint_map)
     elif os.path.isfile(base_path) and base_path.endswith('.yaml'):
         failed = validate(base_path, param_map)
         if failed:
@@ -1430,30 +1378,6 @@ for base_path in path_args:
         print('Unexpected argument %s' % base_path)
         exit_usage()
 
-if base_endpoint_map and \
-        len(env_endpoint_maps) == len(envs_containing_endpoint_map):
-    for env_endpoint_map in env_endpoint_maps:
-        matches = validate_endpoint_map(base_endpoint_map,
-                                        env_endpoint_map['map'])
-        if not matches:
-            print("ERROR: %s needs to be updated to match changes in base "
-                  "endpoint map" % env_endpoint_map['file'])
-            failed_files.append(env_endpoint_map['file'])
-            exit_val |= 1
-        elif args.quiet < 1:
-            print("%s matches base endpoint map" % env_endpoint_map['file'])
-else:
-    print("ERROR: Did not find expected number of environments containing the "
-          "EndpointMap parameter.  If you meant to add or remove one of these "
-          "environments then you also need to update this tool.")
-    if not base_endpoint_map:
-        failed_files.append(ENDPOINT_MAP_FILE)
-    if len(env_endpoint_maps) != len(envs_containing_endpoint_map):
-        matched_files = set(os.path.basename(matched_env_file['file'])
-                            for matched_env_file in env_endpoint_maps)
-        failed_files.extend(set(envs_containing_endpoint_map) - matched_files)
-    exit_val |= 1
-
 # Validate that duplicate parameters defined in multiple files all have the
 # same definition.
 mismatch_count = 0
